@@ -1,18 +1,17 @@
 /*
  * The XML and API file generator module for SIP.
  *
- * Copyright (c) 2009 Riverbank Computing Limited <info@riverbankcomputing.com>
- * 
+ * Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+ *
  * This file is part of SIP.
- * 
+ *
  * This copy of SIP is licensed for use under the terms of the SIP License
  * Agreement.  See the file LICENSE for more details.
- * 
+ *
  * This copy of SIP may also used under the terms of the GNU General Public
  * License v2 or v3 as published by the Free Software Foundation which can be
- * found in the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this
- * package.
- * 
+ * found in the files LICENSE-GPL2 and LICENSE-GPL3 included in this package.
+ *
  * SIP is supplied WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
@@ -240,7 +239,8 @@ static int apiOverload(sipSpec *pt, moduleDef *mod, classDef *scope,
     prScopedPythonName(fp, scope, od->common->pyname->text);
     fprintf(fp, "?%d", METHOD_ID);
 
-    need_sec = prPythonSignature(pt, fp, &od->pysig, sec, TRUE, TRUE, FALSE);
+    need_sec = prPythonSignature(pt, fp, &od->pysig, sec, TRUE, TRUE, FALSE,
+            FALSE);
 
     fprintf(fp, "\n");
 
@@ -271,15 +271,15 @@ static int apiArgument(sipSpec *pt, argDef *ad, int out, int need_comma,
 
     prScopedPythonName(fp, tscope, tname);
 
-    if (names && ad->name != NULL)
-        fprintf(fp, " %s", ad->name->text);
-
     /*
      * Handle the default value is required, but ignore it if it is an output
      * only argument.
      */
     if (defaults && ad->defval && !out)
     {
+        if (names && ad->name != NULL)
+            fprintf(fp, " %s", ad->name->text);
+
         fprintf(fp, "=");
         prcode(fp, "%M");
         exportDefaultValue(ad, in_str, fp);
@@ -366,6 +366,9 @@ static void xmlClass(sipSpec *pt, moduleDef *mod, classDef *cd, FILE *fp)
     if (cd->convtocode != NULL)
         fprintf(fp, " convert=\"1\"");
 
+    if (cd->convfromcode != NULL)
+        fprintf(fp, " convertfrom=\"1\"");
+
     if (cd->real != NULL)
         fprintf(fp, " extends=\"%s\"", cd->real->iff->module->name);
 
@@ -778,7 +781,6 @@ static void xmlType(sipSpec *pt, argDef *ad, int sec, FILE *fp)
         break;
 
     case mapped_type:
-        prcode(fp, "%M%B%M", &ad->u.mtd->type);
         type_type = "mappedtype";
         break;
     }
@@ -941,6 +943,10 @@ static const char *pyType(sipSpec *pt, argDef *ad, int sec, classDef **scope)
 
     switch (ad->atype)
     {
+    case capsule_type:
+        type_name = scopedNameTail(ad->u.cap);
+        break;
+
     case struct_type:
     case void_type:
         type_name = "sip.voidptr";
@@ -987,6 +993,9 @@ static const char *pyType(sipSpec *pt, argDef *ad, int sec, classDef **scope)
         type_name = "str";
         break;
 
+    case byte_type:
+    case sbyte_type:
+    case ubyte_type:
     case ushort_type:
     case uint_type:
     case long_type:
@@ -1039,6 +1048,10 @@ static const char *pyType(sipSpec *pt, argDef *ad, int sec, classDef **scope)
         type_name = "type";
         break;
 
+    case pybuffer_type:
+        type_name = "buffer";
+        break;
+
     case ellipsis_type:
         type_name = "...";
         break;
@@ -1076,11 +1089,19 @@ void prScopedPythonName(FILE *fp, classDef *scope, const char *pyname)
  * Generate a Python signature.
  */
 int prPythonSignature(sipSpec *pt, FILE *fp, signatureDef *sd, int sec,
-        int names, int defaults, int in_str)
+        int names, int defaults, int in_str, int is_signal)
 {
     int need_sec = FALSE, need_comma = FALSE, is_res, nr_out, a;
 
-    fprintf(fp, "(");
+    if (is_signal)
+    {
+        if (sd->nrArgs != 0)
+            fprintf(fp, "[");
+    }
+    else
+    {
+        fprintf(fp, "(");
+    }
 
     nr_out = 0;
 
@@ -1101,7 +1122,16 @@ int prPythonSignature(sipSpec *pt, FILE *fp, signatureDef *sd, int sec,
             need_sec = TRUE;
     }
 
-    fprintf(fp, ")");
+    if (is_signal)
+    {
+        if (sd->nrArgs != 0)
+            fprintf(fp, "]");
+    }
+    else
+    {
+        fprintf(fp, ")");
+    }
+
 
     is_res = !((sd->result.atype == void_type && sd->result.nrderefs == 0) ||
             (sd->result.doctype != NULL && sd->result.doctype[0] == '\0'));
