@@ -1,7 +1,7 @@
 /*
  * The parse tree transformation module for SIP.
  *
- * Copyright (c) 2013 Riverbank Computing Limited <info@riverbankcomputing.com>
+ * Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
  *
  * This file is part of SIP.
  *
@@ -1789,7 +1789,11 @@ static void getClassVirtuals(classDef *base, classDef *cd)
                 {
                     is_nearer = TRUE;
 
-                    if (sameSignature(nod->cppsig, od->cppsig, TRUE) && isConst(nod) == isConst(od) && !isAbstract(nod))
+                    /*
+                     * Re-implementations explicitly marked as virtual will
+                     * already have been handled.
+                     */
+                    if (!isVirtual(nod) && sameSignature(nod->cppsig, od->cppsig, TRUE) && isConst(nod) == isConst(od) && !isAbstract(nod))
                         reimp = nod;
 
                     break;
